@@ -73,11 +73,19 @@ def preprocessing_training_common(df, config, model_type: str, mapping_dicts=Non
         mapping_dicts['industry_prob'] = industry_prob_dictionary
         mapping_dicts['industry_bv'] = industry_bv_dictionary
 
+        logging.info(mapping_dicts['industry_prob'])
+        logging.info(mapping_dicts['industry_bv'])
+        logging.info(mapping_dicts['mx_prob'])
+        logging.info(mapping_dicts['mx_bv'])
+        logging.info(mapping_dicts['state_prob'])
+        logging.info(mapping_dicts['state_bv'])
+
         mapping_dicts_name = config['mapping_dicts_name']
         mapping_dicts_output_path = os.path.join('/opt/ml/processing/mapping_dicts', mapping_dicts_name)
         logging.info('Saving dicts to {}'.format(mapping_dicts_output_path))
-        pickle.dump(imp, open(mapping_dicts_output_path, 'wb'))
+        pickle.dump(mapping_dicts, open(mapping_dicts_output_path, 'wb'))
     else:
+        logging.info("Mapping dicts found! Using them")
         df = devutils.map_conv_prob_using_dictionary(df, mapping_dicts['mx_prob'], mapping_dicts['mx_bv'], 'MXType')
         df = devutils.map_conv_prob_using_dictionary(df, mapping_dicts['state_prob'], mapping_dicts['state_bv'],
                                                      'State')
@@ -158,6 +166,7 @@ def preprocessing_training(df, config, model_type,
         model_type(string) : can be probability, bv or multiclass
     Returns:
         df_clean[Pandas Dataframe]: Pre-processed DataFrame ready for training purposes
+        :param use_one_hot_encoding:
         :param mapping_dicts:
     """
 
