@@ -538,12 +538,16 @@ def clean_mxtype(df, mxtypes):
     return df
 
 
-def create_class_dictionaries(df,class_to_use:str):
+def create_class_dictionaries(df_original,class_to_use:str):
+    logger.info(f'Creating dictionaries for {class_to_use}')
+    df=df_original[[class_to_use, 'BV', 'IDEmailStatus']].copy()
     df['BV']=df['BV'].fillna(0)
-    groupby = df[[class_to_use, 'BV', 'IDEmailStatus']].groupby(class_to_use).agg(BV=('BV', 'mean'),
-                                                                                 Conversions=(
-                                                                                     'IDEmailStatus', 'mean'))
+    logger.info(f"{df['BV'].value_counts(dropna=False)}")
+    groupby = df.groupby(class_to_use).agg(BV=('BV', 'mean'),
+                                           Conversions=('IDEmailStatus', 'mean')
+                                           )
     groupby = groupby.reset_index()
+    logger.info(f"{groupby.head()}")
     list_dict = groupby.to_dict(orient='records')
     conversion_dict = {}
     bv_dict = {}
@@ -563,7 +567,7 @@ def map_conv_prob_using_dictionary(df, bv_dict, prob_dict, column:str):
 
     if column not in df.columns:
         raise Exception("MXType column not preset ( Check Caps)")
-    logger.info(f'Defining dict for {column}')
+    logger.info(f'mapping bv and prob dicts for {column}')
     bv_col = column+"_bv"
     df[bv_col] = df[column].map(bv_dict)
     prob_col = column+"_prob"
